<?php
/**
 * Plugin Name: WooCommerce YouTube Video (By EasyToolsWP)
 * Description: Add a YouTube video to WooCommerce products and choose where it should appear.
 * Version: 1.1
 * Author: EasyToolsWP
 * Author URI: https://www.easytoolswp.com
 * Text Domain: etwp-woo-youtube-video
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Add custom field to product edit page
function wc_youtube_video_custom_fields() {
    global $post;
    echo '<div class="options_group">';
    
    woocommerce_wp_text_input(
        array(
            'id' => '_youtube_video_url',
            'label' => __('YouTube Video URL', 'wc-youtube-video'),
            'placeholder' => 'https://www.youtube.com/watch?v=',
            'description' => __('Insert the URL of the YouTube video.', 'wc-youtube-video'),
            'type' => 'text'
        )
    );
    
    woocommerce_wp_select(
        array(
            'id' => '_youtube_video_position',
            'label' => __('Video Position', 'wc-youtube-video'),
            'options' => array(
                'short_description' => __('Short Description', 'wc-youtube-video'),
                'long_description' => __('Long Description', 'wc-youtube-video'),
                'under_image' => __('Under Image', 'wc-youtube-video'),
                'replace_image' => __('Replace Image', 'wc-youtube-video')
            ),
            'description' => __('Choose where the video should appear on the product page.', 'wc-youtube-video')
        )
    );
    
    echo '</div>';
}
add_action('woocommerce_product_options_general_product_data', 'wc_youtube_video_custom_fields');

// Save custom field values
function wc_youtube_video_save_custom_fields($post_id) {
    $youtube_video_url = isset($_POST['_youtube_video_url']) ? sanitize_text_field($_POST['_youtube_video_url']) : '';
    $youtube_video_position = isset($_POST['_youtube_video_position']) ? sanitize_text_field($_POST['_youtube_video_position']) : '';
    
    update_post_meta($post_id, '_youtube_video_url', $youtube_video_url);
    update_post_meta($post_id, '_youtube_video_position', $youtube_video_position);
}
add_action('woocommerce_process_product_meta', 'wc_youtube_video_save_custom_fields');

// Display YouTube video on product page
function wc_youtube_video_display() {
    global $product;
    
    $youtube_video_url = get_post_meta($product->get_id(), '_youtube_video_url', true);
    $youtube_video_position = get_post_meta($product->get_id(), '_youtube_video_position', true);
    
    if ($youtube_video_url) {
        $embed_url = str_replace('watch?v=', 'embed/', $youtube_video_url);
        $iframe = '<iframe width="560" height="315" src="' . esc_url($embed_url) . '" frameborder="0" allowfullscreen></iframe>';
        
        switch ($youtube_video_position) {
            case 'short_description':
                add_action('woocommerce_single_product_summary', function() use ($iframe) {
                    echo $iframe;
                }, 20);
                break;
            case 'long_description':
                add_action('woocommerce_after_single_product_summary', function() use ($iframe) {
                    echo $iframe;
                }, 5);
                break;
            case 'under_image':
                add_action('woocommerce_product_thumbnails', function() use ($iframe) {
                    echo $iframe;
                }, 5);
                break;
            case 'replace_image':
                add_action('woocommerce_before_single_product_summary', function() use ($iframe) {
                    echo $iframe;
                }, 5);
                add_action('woocommerce_before_single_product_summary', function() {
                    remove_action('woocommerce_before_single_product_summary', 'woocommerce_show_product_images', 20);
                }, 1);
                break;
        }
    }
}
add_action('woocommerce_before_single_product', 'wc_youtube_video_display');
